@@ -13,12 +13,15 @@
 # pylint: disable= redefined-outer-name
 # Отлючено для удобства чтения функций загрузки страниц web-приложения
 
+# pylint: disable= too-many-return-statements
+# Отлючено для удобства обработки исключений при вызове функции flash()
+
 # pylint: disable= no-member
 
 import argparse
 import os
 from fileinput import FileInput
-from flask import Flask, render_template, request, redirect
+from flask import Flask, render_template, request, flash
 import slush_list
 
 
@@ -28,6 +31,7 @@ ALLOWED_EXTENSIONS = {'txt'}
 app = Flask(__name__)
 app.config.from_json('microservice_cfg.json')
 app.config['UPLOAD_FOLDER'] = UPLOAD_FOLDER
+app.secret_key = 'some_secret'
 
 
 @app.route('/', methods=['GET', 'POST'])
@@ -35,22 +39,33 @@ def index():
     """Основная страница web-приложения"""
 
     if request.method == 'POST':
-        fullname = request.form['fullname']
+        fullname = request.form.get('fullname')
+
+        if fullname == '':
+
+            message = 'fullname не введен'
+
+            flash(message, category='error')
+
+            return render_template("index.html")
 
         cheak_name = fullname.split('-')
 
         if len(cheak_name) < 4:
-            url = ''
-            message = "ERROR (Неверно указан fullname)"
 
-            return render_template("message.html", message=message, url=url)
+            message = 'Неверно введенный fullname'
+
+            flash(message, category='error')
+
+            return render_template("index.html")
 
         if not get_stud(fullname):
 
-            url = ''
-            message = "ERROR (fullname не найден)"
+            message = 'fullname не найден'
 
-            return render_template("message.html", message=message, url=url)
+            flash(message, category='error')
+
+            return render_template("index.html")
 
         else:
 
@@ -84,9 +99,25 @@ def load():
     """Страница загрузки списка группы"""
 
     if request.method == 'POST':
-        year = request.form['year']
-        number = request.form['number']
-        file = request.files['file']
+        year = request.form.get('year')
+        number = request.form.get('number')
+        file = request.files.get('file')
+
+        print(file)
+
+        if year is None:
+
+            message = 'Не указан год поступления'
+            flash(message, category='error')
+
+            return render_template("load.html")
+
+        if number == '':
+
+            message = 'Не указан порядковый номер группы'
+            flash(message, category='error')
+
+            return render_template("load.html")
 
         if file and allowed_file(file.filename):
 
@@ -97,32 +128,39 @@ def load():
             load_list = slush_list.Students(year, number)
             key = f"{year}-{number}"
             if key in groups_dir:
-                url = 'load'
-                message = "ERROR (Группа с таким названием уже загружена)"
 
-                return render_template("message.html", message=message, url=url)
+                message = "Группа с таким названием уже загружена"
+
+                flash(message, category='error')
+
+                return render_template("load.html")
 
             if load_list.read_slush(f"{UPLOAD_FOLDER}/{filename}"):
 
                 group_name = load_list.load_slush()
                 groups_dir[group_name] = load_list
 
-                return redirect('/')
+                message = 'Группа загружена'
+
+                flash(message, category='success')
+
+                return render_template("load.html")
             else:
 
                 os.remove(f"{UPLOAD_FOLDER}/{filename}")
 
-                url = 'load'
-                message = "ERROR (Введенные данные указаны неверно)"
+                message = "Введенные данные указаны неверно"
 
-                return render_template("message.html", message=message, url=url)
+                flash(message, category='error')
+
+                return render_template("load.html")
         else:
 
-            url = 'load'
-            message = "ERROR (Неверный формат файла)"
+            message = "Неверный формат файла"
 
-            return render_template("message.html", message=message, url=url)
+            flash(message, category='error')
 
+            return render_template("load.html")
 
     else:
         return render_template("load.html")
@@ -182,24 +220,33 @@ def delete_group():
     """страница удаления загруженной группы"""
 
     if request.method == 'POST':
-        group = request.form['group']
+        group = request.form.get('group')
+
+        if group == '':
+
+            message = 'Не указана группа'
+            flash(message, category='error')
+
+            return render_template("groupdel.html")
 
         try:
             del groups_dir[group]
 
             os.remove(f"./group_lists/{group}.txt")
 
-            url = ''
             message = 'Группа удалена'
 
-            return render_template("message.html", message=message, url=url)
+            flash(message, category='success')
+
+            return render_template("groupdel.html")
 
         except KeyError:
 
-            url = 'delete'
-            message = "ERROR (Введенный номер группы отсутствует в списке)"
+            message = "Введенный номер группы отсутствует в списке"
 
-            return render_template("message.html", message=message, url=url)
+            flash(message, category='error')
+
+            return render_template("groupdel.html")
 
     return render_template("groupdel.html")
 
@@ -208,15 +255,38 @@ def delete_group():
 def relogin():
     """страница изменения login слушателя"""
 
+    group = list(groups_dir.keys())
+
     if request.method == 'POST':
-        group = request.form['group']
-        old_login = request.form['old']
-        new_login = request.form['new']
+        number_group = request.form.get('group')
+        old_login = request.form.get('old_login')
+        new_login = request.form.get('new_login')
+
+        if number_group is None:
+
+            message = 'Не указана группа'
+            flash(message, category='error')
+
+            return render_template("relogin.html", group=group)
+
+        if old_login == '':
+
+            message = 'Не указан старый login'
+            flash(message, category='error')
+
+            return render_template("relogin.html", group=group)
+
+        if new_login == '':
+
+            message = 'Не указан новый login'
+            flash(message, category='error')
+
+            return render_template("relogin.html", group=group)
 
         try:
-            groups_dir[group].relogin(old_login, new_login)
+            groups_dir[number_group].relogin(old_login, new_login)
 
-            for line in FileInput(f"{UPLOAD_FOLDER}/{group}.txt", inplace=True):
+            for line in FileInput(f"{UPLOAD_FOLDER}/{number_group}.txt", inplace=True):
                 login = line.split(';')
                 login[2] = login[2][:-1]
                 if login[2] == old_login:
@@ -224,21 +294,22 @@ def relogin():
                     line = ';'.join(login)
                 print(line, end='')
 
-            url = ''
-            message = 'Login успешно изменен'
+            message = 'Login изменен'
 
-            return render_template("message.html", message=message, url=url)
+            flash(message, category='success')
+
+            return render_template("relogin.html", group=group)
 
         except ValueError:
 
-            url = 'relogin'
-            message = "ERROR (Введенный login отсутствует в списке)"
+            message = "Введенный login отсутствует в списке"
+
+            flash(message, category='error')
+
+            return render_template("relogin.html", group=group)
 
-            return render_template("message.html", message=message, url=url)
     else:
 
-        group = list(groups_dir.keys())
-
         return render_template("relogin.html", group=group)
 
 
@@ -246,15 +317,56 @@ def relogin():
 def rename():
     """Страница изменения fullname слушателя"""
 
+    group = list(groups_dir.keys())
+
     if request.method == 'POST':
-        group = request.form['group']
-        login = request.form['login']
-        new_name = request.form['new']
+        number_group = request.form.get('group')
+        login = request.form.get('login')
+        new_name = request.form.get('new')
+
+        if number_group is None:
+
+            message = 'Не указана группа'
+            flash(message, category='error')
+
+            return render_template("rename.html", group=group)
+
+        if login == '':
+
+            message = 'Не указан login'
+            flash(message, category='error')
+
+            return render_template("rename.html", group=group)
+
+        if new_name == '':
+
+            message = 'Не указан новый fullname'
+            flash(message, category='error')
+
+            return render_template("rename.html", group=group)
+
+        gr_year, gr_num = number_group.split('-')
+
+        new_fullname = new_name.split('-')
+
+        if gr_year != new_fullname[0]:
+
+            message = 'Не верно указан год поступления в новом fullname'
+            flash(message, category='error')
+
+            return render_template("rename.html", group=group)
+
+        if gr_num != new_fullname[1]:
+
+            message = 'Не верно указан порядковый номер группы в новом fullname'
+            flash(message, category='error')
+
+            return render_template("rename.html", group=group)
 
         try:
-            if groups_dir[group].rename(login, new_name):
+            if groups_dir[number_group].rename(login, new_name):
 
-                for line in FileInput(f"{UPLOAD_FOLDER}/{group}.txt", inplace=True):
+                for line in FileInput(f"{UPLOAD_FOLDER}/{number_group}.txt", inplace=True):
                     fullname = line.split(';')
                     fullname[2] = fullname[2][:-1]
                     if fullname[2] == login:
@@ -262,28 +374,29 @@ def rename():
                         line = ';'.join(fullname) + '\n'
                     print(line, end='')
 
-                url = ''
-                message = 'Fullname успешно изменен'
+                message = 'Fullname изменен'
 
-                return render_template("message.html", message=message, url=url)
+                flash(message, category='success')
+
+                return render_template("rename.html", group=group)
 
             else:
 
-                url = 'rename'
-                message = "ERROR (Новый fullname введен некорректно)"
+                message = "Новый fullname введен некорректно"
 
-                return render_template("message.html", message=message, url=url)
+                flash(message, category='error')
+
+                return render_template("rename.html", group=group)
 
         except ValueError:
 
-            url = 'rename'
-            message = "ERROR (Введенный login отсутствует в списке)"
+            message = "Введенный login отсутствует в списке"
 
-            return render_template("message.html", message=message, url=url)
+            flash(message, category='error')
+
+            return render_template("relogin.html", group=group)
     else:
 
-        group = list(groups_dir.keys())
-
         return render_template("rename.html", group=group)
 
 
@@ -291,31 +404,52 @@ def rename():
 def repos():
     """Страница со списками репозиториев"""
 
+    group = list(groups_dir.keys())
+
     if request.method == 'POST':
-        choice = request.form['choice']
-        group = request.form['group']
-        repo_name = request.form['repo_name']
+        choice = request.form.get('choice')
+        number_group = request.form.get('group')
+        repo_name = request.form.get('repo_name')
+
+        if choice is None:
+
+            message = 'Не указана операция'
+            flash(message, category='error')
+
+            return render_template("getrepos.html", group=group)
+
+        if number_group == '':
+
+            message = 'Не указана группа'
+            flash(message, category='error')
+
+            return render_template("getrepos.html", group=group)
+
+        if repo_name == '':
+
+            message = 'Не указано имя репозитория или группы'
+            flash(message, category='error')
+
+            return render_template("getrepos.html", group=group)
 
         sl_list = []
 
         if choice == 'repo':
             flag = '-r'
-            sl_list = get_repos(group, repo_name, flag)
+            sl_list = get_repos(number_group, repo_name, flag)
 
-            return render_template("showrepos.html", group=group, sl_list=sl_list)
+            return render_template("showrepos.html", group=number_group, sl_list=sl_list)
 
         elif choice == 'group':
             flag = '-g'
-            sl_list = get_repos(group, repo_name, flag)
+            sl_list = get_repos(number_group, repo_name, flag)
 
-            return render_template("showgroups.html", group=group, sl_list=sl_list)
+            return render_template("showgroups.html", group=number_group, sl_list=sl_list)
 
         return None
 
     else:
 
-        group = list(groups_dir.keys())
-
         return render_template("getrepos.html", group=group)
 
 
